@@ -22,23 +22,6 @@
 #define MAX_NON_PRELOAD_LIBS_LEN 2048
 #define FILE_EXT ".so"
 
-// Locations where shell file can be found
-#ifndef ENABLE_UPSTREAM_DRIVER_INTERFACE
-#ifndef DSP_MOUNT_LOCATION
-#define DSP_MOUNT_LOCATION "/dsp/"
-#endif
-#ifndef DSP_DOM_LOCATION
-#define DSP_DOM_LOCATION "/dsp/xdsp"
-#endif
-#else /* ENABLE_UPSTREAM_DRIVER_INTERFACE */
-#ifndef DSP_MOUNT_LOCATION
-#define DSP_MOUNT_LOCATION "/usr/lib/dsp/"
-#endif
-#ifndef DSP_DOM_LOCATION
-#define DSP_DOM_LOCATION "/usr/lib/dsp/xdspn"
-#endif
-#endif /* ENABLE_UPSTREAM_DRIVER_INTERFACE */
-
 #ifndef VENDOR_DSP_LOCATION
 #define VENDOR_DSP_LOCATION "/vendor/dsp/"
 #endif
@@ -46,14 +29,12 @@
 #define VENDOR_DOM_LOCATION "/vendor/dsp/xdsp/"
 #endif
 
-// Search path used by fastRPC to search skel library, .debugconfig and .farf files
-#ifndef DSP_SEARCH_PATH
-#define DSP_SEARCH_PATH ";/usr/lib/rfsa/adsp;/vendor/lib/rfsa/adsp;/vendor/dsp/;/usr/lib/dsp/;"
-#endif
-
 // Search path used by fastRPC for acdb path
 #ifndef ADSP_AVS_CFG_PATH
 #define ADSP_AVS_CFG_PATH ";/etc/acdbdata/;"
 #endif
 
+int fopen_from_dirlist(const char *dirList, const char *delim, 
+    const char *mode, const char *name, apps_std_FILE *psout);
+
 #endif /*__APPS_STD_INTERNAL_H__*/
